aerosoltools.aerosol2d.Aerosol2D.timerebin — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.timerebin

Aerosol2D.timerebin(freq='s', method='mean', inplace=True)

  Resample the data to a new time frequency using an aggregation function.

  ## Parameters

  freqstr, optional

    Resampling frequency. Naming convention is ‘s’, ‘min’, or ‘h’ for seconds, minutes and hours but these can be combined with integers e.g., ‘30S’, ‘5min’, or ‘1H’. Default is ‘s’.

  methodstr or function, optional

    Aggregation method to apply e.g., ‘mean’, ‘median’, ‘sum’, ‘min’, ‘max’, or a custom function. Default is ‘mean’.

  inplacebool, optional

    If True, modifies the object in place. If False, returns a new rebinned object. Default is True.

  ## Returns

  Aerosol1D

    Instance of Aerosol1D with rebinned time index.

  Parameters:

    - freq (str)

    - method (str)

    - inplace (bool)